@@ -13,15 +13,16 @@ NumericVector calcDistance(const IntegerVector& p,
     NumericVector d(y.begin(), y.end());
     double val;
     int i, j;
-    bool haveChange=true;
+    bool changes = true;
+
+    while(changes) {
+        changes = false;
 
-    while(haveChange) {
-        haveChange=false;
         for(i=0; i<d.size(); i++) {
             for(j=p[i]; j<p[i+1]; j++) {
                 val = d[idx[j]] * x[j];
                 if(val > d[i]) {
-                    haveChange=true;
+                    changes = true;
                     d[i] = val;
                 }
             }
